@@ -1,24 +1,24 @@
 ################################
-#### Summary statistics for cicular data 
-#### Tsagris Michail 6/2014 
+#### Summary statistics for cicular data
+#### Tsagris Michail 6/2014
 #### mtsagris@yahoo.gr
 #### References: S Rao Jammalamadaka and A SenGupta (2001)
-#### Topics in circular statistics 
+#### Topics in circular statistics
 #### References: Mardia Kanti V. and Jupp Peter E. (2000)
-#### Directional statistics, page 124 
+#### Directional statistics, page 124
 ################################
 
-circ.summary <- function(u, rads = F, plot = T) {
+circ.summary <- function(u, rads = FALSE, plot = TRUE) {
   ## u is an angular variable
   n <- length(u)  ## sample size
   ## if the data are in degrees we transform them into radians
-  if (rads == F)  u <- u * pi/180
+  if (rads == FALSE)  u <- u * pi/180
   ## mesos contains the sample mean
   ## direction
   C <- mean( cos(u) )
   S <- mean( sin(u) )
   Rbar <- sqrt(C^2 + S^2)  ## mean resultant length
-  if (C > 0) {   
+  if (C > 0) {
     mesos <- atan(S/C)
   } else  mesos <- atan(S/C) + pi
   MRL <- Rbar  ## mean resultant length
@@ -26,19 +26,19 @@ circ.summary <- function(u, rads = F, plot = T) {
   circs <- sqrt(-2 * log(Rbar))  ## sample cicrular standard deviation
   ## lik is the von Mises likelihood
    lik <- function(k) {
-     f <- k * sum(cos(u - mesos)) - n * log(2 * pi) - 
-     n * (log(besselI(k, 0, expon.scaled = T)) + k)
+     f <- k * sum( cos(u - mesos) ) - n * log(2 * pi) -
+     n * (log(besselI( k, 0, expon.scaled = TRUE) ) + k)
      f
    }
-  kappa <- optimize(lik, c(0, 100000), maximum = TRUE)$maximum  
+  kappa <- optimize(lik, c(0, 100000), maximum = TRUE)$maximum
   ## kappa is the estimated concentration (kappa)
   R <- n * Rbar
   if (Rbar < 2/3) {
-    fact <- sqrt(2 * n * (2 * R^2 - n * qchisq(0.95, 1))/
-    (R^2 * (4 * n - qchisq(0.95, 1))))
+    fact <- sqrt(2 * n * (2 * R^2 - n * qchisq(0.05, 1))/
+    (R^2 * (4 * n - qchisq(0.05, 1))))
     ci <- c(mesos - acos(fact), mesos + acos(fact))
-  } else  { 
-    fact <- sqrt(n^2 - (n^2 - R^2) * exp(qchisq(0.95, 1)/n))/R
+  } else  {
+    fact <- sqrt(n^2 - (n^2 - R^2) * exp(qchisq(0.05, 1)/n))/R
     ci <- c(mesos - acos(fact), mesos + acos(fact))
   }
   if (rads == F) {
@@ -55,6 +55,6 @@ circ.summary <- function(u, rads = F, plot = T) {
     lines(yy, t, lty = 2)
     points(cos(u), sin(u))
   }
-  list(mesos = mesos, confint = ci, kappa = kappa, MRL = MRL, 
+  list(mesos = mesos, confint = ci, kappa = kappa, MRL = MRL,
   circvariance = circv, circstd = circs)
 }
