@@ -12,23 +12,23 @@
 
 mediandir_2 = function(x) {
   ## x is the directional data
-
   x = as.matrix(x)
   x = x / sqrt( rowSums(x^2) )
   n = nrow(x)  ;  p = ncol(x)
-  pa = colMeans(x)
-  u <- matrix(nrow = 1000, ncol = p)
-  u[1, ] <- pa / sqrt( sum(pa^2) )
-  ww <- as.vector( sqrt( 1 - ( x %*% u[1, ] )^2 ) )
-  u[2, ] <- colSums( x / ww )
-  u[2, ] <- u[2, ] / sqrt( sum(u[2, ]^2) )
-  i <- 2
 
+  pa = colMeans(x)
+  u <- matrix(nrow = 10000, ncol = p)
+  u[1, ] <- pa / sqrt( sum(pa^2) )
+  ww <- as.vector( sqrt( 1 - ( x %*% pa )^2 ) )
+  u[2, ] <- colSums(x / ww )
+  u[2, ] <- u[2, ] / sqrt(sum(u[2, ]^2))
+
+  i <- 2
   while ( sum( abs(u[i, ] - u[i - 1, ]) ) > 1e-10 ) {
     i <- i +1
     ww <- as.vector( sqrt( 1 - ( x %*% u[i - 1, ] )^2 ) )
     u[i, ] <- colSums(x / ww )
-    u[i, ] <- u[i, ] / sqrt( sum(u[i, ]^2) )
+    u[i, ] <- u[i, ] / sqrt(sum(u[i, ]^2))
   }
 
   u[i, ]
