@@ -1,7 +1,7 @@
 ################################
 #### Discrminant analysis for directional data
 #### assuming a von Mises-Fisher distribution
-#### Tsagris Michail 03/2014 
+#### Tsagris Michail 03/2014
 #### mtsagris@yahoo.gr
 #### References: J. E. Morris and P. J. Laycock (1974)
 #### Discriminant Analysis of Directional Data (Biometrika)
@@ -28,10 +28,10 @@ vmfda.pred <- function(xnew, x, ina) {
     da <- vmf(x[ina == j, ])  ## estimates the parameters of the vMF
     mesi[j, ] <- da$mu  ## mean direction
     k[j] <- da$k  ## concentration
-  }  
+  }
   for (j in 1:g) {
-    mat[, j] <- (p/2 - 1) * log(k[j]) + k[j] * xnew %*% mesi[j, ] - 0.5 * p * 
-    log(2 * pi) - log(besselI(k[j], p/2 - 1, expon.scaled = T)) - k[j]
+    mat[, j] <- (p/2 - 1) * log(k[j]) + k[j] * xnew %*% mesi[j, ] - 0.5 * p *
+    log(2 * pi) - log(besselI(k[j], p/2 - 1, expon.scaled = TRUE)) - k[j]
   }
   apply(mat, 1, which.max)
-}
\ No newline at end of file
+}
